@@ -1,5 +1,6 @@
 import requests
 from typing import List
+import logging
 
 
 def chat_gpt(key, prompt, text):
@@ -17,6 +18,11 @@ def chat_gpt(key, prompt, text):
     }
     response = requests.post(
         'https://api.openai.com/v1/chat/completions', headers=headers, json=json_data)
+    # Return Error message if response is not 200
+    if response.status_code != 200:
+        logging.info('response:', response.content)
+        return str(response.json()['error'])
+
     return response.json()['choices'][0]['message']['content']
 
 
