@@ -2,7 +2,7 @@ import requests
 import yt_dlp
 from typing import Dict, Any, List
 from .gpt import seg_transcript, chat_gpt
-from .utils import is_valid_youtube_url
+from datetime import datetime
 import traceback
 import re
 
@@ -68,6 +68,13 @@ class HytGpt:
     @staticmethod
     def build_youtube_url(youtube_id: str) -> str:
         return f'https://www.youtube.com/watch?v={youtube_id}'
+    
+    @staticmethod
+    def get_timestamp_diff(start_time, end_time):
+        start_time = datetime.strptime(start_time, '%H:%M:%S.%f')
+        end_time = datetime.strptime(end_time, '%H:%M:%S.%f')
+        diff = (end_time - start_time).total_seconds()
+        return diff
 
 
     def __youtube_player_list(self, yvid):
@@ -89,6 +96,7 @@ class HytGpt:
                 continue
             start, end = subtitle_lines[i].split(' --> ')
             text = subtitle_lines[i+1]
+
             result.append({
                 'start': start,
                 'end': end,
@@ -96,10 +104,26 @@ class HytGpt:
             })
         return result
 
-
-    def __prepare_subtitle(self, subtitle: Dict[str, str]) -> str:
-        text = self.__get_text_from_url(subtitle.get('url'))
-        return self.__parse_subtitles(text)
+    def __parse_requested_subtitles(self, requested_subtitles) -> List[Dict[str, str]]:
+        result = []
+        subtitle_lines = requested_subtitles.strip().split('\n')[3:]
+        for i in range(0, len(subtitle_lines), 1):
+            match_timestamp = re.match(r'(\d{2}:\d{2}:\d{2}\.\d{3})\s*-->\s*(\d{2}:\d{2}:\d{2}\.\d{3})', subtitle_lines[i])
+            if not match_timestamp:
+                continue
+            start = match_timestamp.group(1)
+            end = match_timestamp.group(2)
+            if self.get_timestamp_diff(start, end) <= 1:
+                continue
+            text = subtitle_lines[i+1]
+            if not re.compile(r'[a-zA-Z]+').search(text):
+                continue
+            result.append({
+                'start': start,
+                'end': end,
+                'text': text
+            })
+        return result        
 
 
     def __youtube_subtitle(self, url: str) -> List[Dict[str, str]]:
@@ -116,10 +140,22 @@ class HytGpt:
 
         # Extract the subtitles
         subtitles = []
-        for subtitle_list in result.get('subtitles', {}).values():
-            for subtitle in subtitle_list:
+        if 'subtitles' in result:
+            for subtitle_list in result['subtitles'].values():
+                for subtitle in subtitle_list:
+                    if subtitle.get('ext') == 'vtt':
+                        text = self.__get_text_from_url(subtitle.get('url'))
+                        subtitles.extend(self.__parse_subtitles(text))
+        
+        if 'requested_subtitles' in result:
+            requested_subtitles = result.get('requested_subtitles')
+            if 'en' in requested_subtitles:
+                subtitle = requested_subtitles['en']
                 if subtitle.get('ext') == 'vtt':
-                    subtitles.extend(self.__prepare_subtitle(subtitle))
+                    print('No subtitles found, fetching requested subtitles.')
+                    text = self.__get_text_from_url(subtitle.get('url'))
+                    subtitles.extend(self.__parse_requested_subtitles(text))
+        print(f'Fetched {len(subtitles)} subtitles.')
         return subtitles
 
 
